audiofadingMarcos
============

#### Esse é um pacote para editar fotos
#### Veja tudo sobre


#### instalação:

    pip install audiofadingMarcos

## uso:

import filterMarcos as fm
img = 'imgs/imagemdeentrada.png'
filter = fm.filterMarcos(img)
fm.apply.filter()